@@ -283,14 +283,18 @@ field3logit <- function(model, delta, label = '', p0 = NULL,
   delta <- pre_process_delta(delta, modB)
   
   # Compute the field(s)
-  delta %>%
-    lapply(function(w) {
+  if ((length(delta) > 1) & (length(label)== 1)) {
+    label %<>% rep(length(delta))
+  }
+  
+  seq_along(delta) %>%
+    lapply(function(j) {
   	  list(
   	    model = modB, p0 = p0, nstreams = nstreams, narrows = narrows,
   	    edge = edge, conf = conf, npoints
   	  ) %>%
-  	  modifyList(w) %>%
-  	  { .[['label']] %<>% paste0(label, .); . } %>%
+  	  modifyList(delta[[j]]) %>%
+  	  { .[['label']] %<>% paste0(label[j], .); . } %>%
   	  do.call('field3logit_mono', .) %>%
   	  return()
     }) %>%
